package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.TaskData;

/**
 * 归因数据回传Mapper接口
 *
 * @author ruoyi
 * @date 2023-10-29
 */
public interface TaskDataMapper
{
    /**
     * 查询归因数据回传
     *
     * @param id 归因数据回传主键
     * @return 归因数据回传
     */
    public TaskData selectTaskDataById(Long id);

    /**
     * 查询归因数据回传列表
     *
     * @param taskData 归因数据回传
     * @return 归因数据回传集合
     */
    public List<TaskData> selectTaskDataList(TaskData taskData);

    /**
     * 新增归因数据回传
     *
     * @param taskData 归因数据回传
     * @return 结果
     */
    public int insertTaskData(TaskData taskData);

    /**
     * 修改归因数据回传
     *
     * @param taskData 归因数据回传
     * @return 结果
     */
    public int updateTaskData(TaskData taskData);

    /**
     * 删除归因数据回传
     *
     * @param id 归因数据回传主键
     * @return 结果
     */
    public int deleteTaskDataById(Long id);

    /**
     * 批量删除归因数据回传
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTaskDataByIds(String[] ids);
}
